==> xlr-sonarqube-plugin-9.6.0.jar: sonar/api/metrics.py <==
#
# Copyright (c) 2019. All rights reserved.
#
# This software and all trademarks, trade names, and logos included herein are the property of XebiaLabs, Inc. and its affiliates, subsidiaries, and licensors.
#
import json
import sys

from sonar import SonarApiService

sonar_server = securityApi.decrypt(configurationApi.getConfiguration(request.query['serverId']))

params = {'url': sonar_server.url, 'username': sonar_server.username,
          'password': sonar_server.password, 'userToken': sonar_server.userToken,
          'proxyHost': sonar_server.proxyHost, 'proxyPort': sonar_server.proxyPort,
          'proxyUsername': sonar_server.proxyUsername, 'proxyPassword': sonar_server.proxyPassword}

http_request = SonarApiService.get_http_request(params)
sonar_response = http_request.get('/api/metrics/search?ps=500')
if sonar_response.isSuccessful():
    json_data = json.loads(sonar_response.getResponse())
    result = {}
    for metric in json_data['metrics']:
        if metric.get('hidden') is not True and metric.get('custom') is not True:
            result[metric.get('key')] = {
                'name': metric.get('name'),
                'type': metric.get('type'),
                'description': metric.get('description')
            }
    response.entity = result
else:
    error = json.loads(sonar_response.getResponse())
    if 'Invalid table' in error['error']['message']:
        print "Invalid Table Name"
        data = {"Invalid table name"}
        sonar_response.errorDump()
    else:
        print "Failed to run query in Sonar"
        sonar_response.errorDump()
    sys.exit(1)

==> xlr-sonarqube-plugin-24.1.1.jar: sonar/api/metrics.py <==
#
# Copyright (c) 2019. All rights reserved.
#
# This software and all trademarks, trade names, and logos included herein are the property of XebiaLabs, Inc. and its affiliates, subsidiaries, and licensors.
#
import json
import sys

from sonar import SonarApiService

sonar_server = securityApi.decrypt(configurationApi.getConfiguration(request.query['serverId']))

params = {'url': sonar_server.url, 'username': sonar_server.username,
          'password': sonar_server.password, 'userToken': sonar_server.userToken,
          'proxyHost': sonar_server.proxyHost, 'proxyPort': sonar_server.proxyPort,
          'proxyUsername': sonar_server.proxyUsername, 'proxyPassword': sonar_server.proxyPassword,
          'proxyDomain': sonar_server.proxyDomain
          }

http_request = SonarApiService.get_http_request(params)
sonar_response = http_request.get('/api/metrics/search?ps=500')
if sonar_response.isSuccessful():
    json_data = json.loads(sonar_response.getResponse())
    result = {}
    for metric in json_data['metrics']:
        if metric.get('hidden') is not True and metric.get('custom') is not True:
            result[metric.get('key')] = {
                'name': metric.get('name'),
                'type': metric.get('type'),
                'description': metric.get('description')
            }
    response.entity = result
else:
    error = json.loads(sonar_response.getResponse())
    if 'Invalid table' in error['error']['message']:
        print "Invalid Table Name"
        data = {"Invalid table name"}
        sonar_response.errorDump()
    else:
        print "Failed to run query in Sonar"
        sonar_response.errorDump()
    sys.exit(1)
